@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import sys
 import load_dot_env
-from usecases.import_relationships import ImportRelationships, ACTION_TYPE_SKIP, ACTION_TYPE_UPDATE
+from _bigbang_core.usecases.import_relationships import ImportRelationships, ACTION_TYPE_SKIP, ACTION_TYPE_UPDATE
 
 DEFAULT_FILE_NAME = 'relationships.csv'
 def main(args = sys.argv):
